@@ -11,13 +11,14 @@ from pipper.environment import Environment
 
 
 def install_pipper_file(
-        local_source_path: str,
-        to_user: bool = False,
-        target_directory: str = None
+    local_source_path: str,
+    to_user: bool = False,
+    target_directory: str = None,
+    dry_run: bool = False,
 ) -> dict:
     """
     Installs the specified local pipper bundle file.
-    
+
     :param local_source_path:
         An absolute path to the pipper bundle file to install
     :param to_user:
@@ -28,19 +29,17 @@ def install_pipper_file(
     :return
         The package metadata from the pipper bundle
     """
-    directory = tempfile.mkdtemp(prefix='pipper-install-')
+    directory = tempfile.mkdtemp(prefix="pipper-install-")
 
     try:
-        extracted = downloader.extract_pipper_file(
-            local_source_path,
-            directory
-        )
+        extracted = downloader.extract_pipper_file(local_source_path, directory)
         wrapper.install_wheel(
-            wheel_path=extracted['wheel_path'],
+            wheel_path=extracted["wheel_path"],
             to_user=to_user,
-            target_directory=target_directory
+            target_directory=target_directory,
+            dry_run=dry_run,
         )
-        return extracted['metadata']
+        return extracted["metadata"]
     except Exception:
         raise
     finally:
@@ -49,19 +48,20 @@ def install_pipper_file(
 
 def install_dependencies(env: Environment, dependencies: typing.List[str]):
     """
-    
+
     :param env:
         Command environment in which this function is being executed
     :param dependencies:
-        A list of package identifiers for dependent packages to be loaded. This 
-        can be either a package name, or a package name and version 
+        A list of package identifiers for dependent packages to be loaded. This
+        can be either a package name, or a package name and version
         (NAME:VERSION) combination, but this version information is ignored for
         dependencies.
     """
+
     def do_install(package_name: str):
         try:
             data = downloader.parse_package_id(env, package_name)
-            existing = wrapper.status(data['name'])
+            existing = wrapper.status(data["name"])
         except Exception:
             existing = wrapper.status(package_name)
         return install(env, package_name) if not existing else None
@@ -74,70 +74,72 @@ def install(env: Environment, package_id: str):
     """
     Installs the specified pipper package, which is specified by either a
     url or a path to a wheel file.
-    
+
     :param env:
         Command environment in which this function is being executed
     :param package_id:
         Identifier for the package to be loaded. This can be either a package
         name, or a package name and version (NAME:VERSION) combination.
     """
-    upgrade = env.args.get('upgrade')
+    upgrade = env.args.get("upgrade")
     data = downloader.parse_package_id(env, package_id)
-    is_url = 'url' in data
+    is_url = "url" in data
 
-    if not upgrade and not data['version'] and wrapper.status(data['name']):
-        print((
-            '[SKIPPED]: "{}" already installed. '
-            'Use the upgrade flag or specify a version if you want to '
-            'change the installed version.'
-        ).format(data['name']))
+    if not upgrade and not data["version"] and wrapper.status(data["name"]):
+        print(
+            (
+                '[SKIPPED]: "{}" already installed. '
+                "Use the upgrade flag or specify a version if you want to "
+                "change the installed version."
+            ).format(data["name"])
+        )
         return
 
-    if not wrapper.update_required(data['name'], data['version']):
-        print('[SKIPPED]: "{}" already installed at version {}'.format(
-            data['name'],
-            data['version']
-        ))
+    if not wrapper.update_required(data["name"], data["version"]):
+        print(
+            '[SKIPPED]: "{}" already installed at version {}'.format(
+                data["name"], data["version"]
+            )
+        )
         return
 
-    remote_version_exists = (
-        is_url
-        or s3.key_exists(env.s3_client, data['bucket'], data['key'])
+    remote_version_exists = is_url or s3.key_exists(
+        env.s3_client, data["bucket"], data["key"]
     )
 
     if not remote_version_exists:
-        print('[ERROR]: Version {} not available for {} package'.format(
-            data['version'],
-            data['name']
-        ))
+        print(
+            "[ERROR]: Version {} not available for {} package".format(
+                data["version"], data["name"]
+            )
+        )
         return
 
-    directory = tempfile.mkdtemp(prefix='pipper-download-')
-    path = os.path.join(directory, 'package.pipper')
+    directory = tempfile.mkdtemp(prefix="pipper-download-")
+    path = os.path.join(directory, "package.pipper")
 
     if is_url:
         downloader.save(package_id, path)
     else:
         env.s3_client.download_file(
-            Bucket=data['bucket'],
-            Key=data['key'],
-            Filename=path
+            Bucket=data["bucket"], Key=data["key"], Filename=path
         )
 
-    print('DOWNLOAD PATH:', os.path.exists(path), path)
+    print("DOWNLOAD PATH:", os.path.exists(path), path)
 
     try:
         metadata = install_pipper_file(
             local_source_path=path,
-            to_user=env.args.get('pip_user'),
-            target_directory=env.args.get('target_directory')
+            to_user=env.args.get("pip_user", False),
+            target_directory=env.args.get("target_directory"),
+            dry_run=bool(env.args.get("dry_run")),
         )
     except Exception:
         raise
     finally:
         shutil.rmtree(directory)
 
-    dependencies = metadata.get('dependencies') or []
+    dependencies = metadata.get("dependencies") or []
     install_dependencies(env, dependencies)
 
 
@@ -145,14 +147,14 @@ def install_many(env: Environment, package_ids: typing.List[str]):
     """
     Installs a list of package identifiers, which can be either package names
     or package name and version combinations.
-    
+
     :param env:
         Command environment in which this function is being executed
     :param package_ids:
         A list of package names or package name and version combinations to
         install
     """
-    for package_id in (package_ids or []):
+    for package_id in package_ids or []:
         install(env, package_id)
 
 
@@ -162,50 +164,53 @@ def install_from_configs(env: Environment, configs_path: str = None):
     path to the configs file is not specified, the default path will be used
     instead. The default location is a pipper.json file in the current
     working directory.
-    
+
     :param env:
         Command environment in which this function is being executed
     :param configs_path:
         Path to a pipper configuration JSON file. If not specified the default
         path will be used instead
     """
-    to_user = env.args.get('pip_user')
-    target_directory = env.args.get('target_directory')
+    to_user = env.args.get("pip_user")
+    target_directory = env.args.get("target_directory")
     configs = environment.load_configs(configs_path)
 
-    for package in configs.get('pypi', []):
-        print('\n=== PYPI {} ==='.format(package))
+    for package in configs.get("pypi", []):
+        print("\n=== PYPI {} ===".format(package))
         wrapper.install_pypi(
             package_name=package,
-            to_user=to_user,
-            target_directory=target_directory
+            to_user=to_user or False,
+            target_directory=target_directory,
+            dry_run=bool(env.args.get("dry_run")),
         )
 
-    for package in configs.get('conda', []):
-        print('\n=== CONDA {} ==='.format(package))
+    for package in configs.get("conda", []):
+        print("\n=== CONDA {} ===".format(package))
         wrapper.install_conda(
             package=package,
-            to_user=to_user,
-            target_directory=target_directory
+            to_user=to_user or False,
+            target_directory=target_directory,
+            dry_run=bool(env.args.get("dry_run")),
         )
 
-    return install_many(env, configs.get('dependencies'))
+    prefix = "dev_" if env.args.get("dev") else ""
+    return install_many(env, configs.get(f"{prefix}dependencies"))
 
 
 def run(env: Environment):
     """
     Executes an installation command action under the given environmental
     conditions. If a packages argument is specified and contains one or more
-    package IDs, they will be installed. If a path to a JSON pipper configs 
+    package IDs, they will be installed. If a path to a JSON pipper configs
     file is specified, that will be installed instead. If nothing has been
     specified, pipper will look for a pipper.json configs file in the current
     directory and use that for installation.
-    
+
     :param env:
         Command environment in which this function is being executed
     """
-    packages = env.args.get('packages')
+    packages = env.args.get("packages")
     if packages:
         return install_many(env, packages)
 
-    install_from_configs(env, env.args.get('configs_path'))
+    install_from_configs(env, env.args.get("configs_path"))
